@@ -5,14 +5,14 @@ xmlString = "<note>\n<to>Tove</to>\n<from>Jani</from>\n<heading>Reminder</headin
 
 # unsafe
 tree = badET.fromstring(xmlString)
-print tree
+print(tree)
 badET.parse('filethatdoesntexist.xml')
 badET.iterparse('filethatdoesntexist.xml')
 a = badET.XMLParser()
 
 # safe
 tree = goodET.fromstring(xmlString)
-print tree
+print(tree)
 goodET.parse('filethatdoesntexist.xml')
 goodET.iterparse('filethatdoesntexist.xml')
 a = goodET.XMLParser()
